Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6560)

Unified Diff: chrome/browser/tracing/crash_service_uploader.cc

Issue 1269773002: Cleanup VersionInfo after componentization. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/tracing/crash_service_uploader.cc
diff --git a/chrome/browser/tracing/crash_service_uploader.cc b/chrome/browser/tracing/crash_service_uploader.cc
index ec7f37f3e5fb6e848e813aac8f65641a2f7c908c..e92637d811038b00ad49d6736936aa3d696b0780 100644
--- a/chrome/browser/tracing/crash_service_uploader.cc
+++ b/chrome/browser/tracing/crash_service_uploader.cc
@@ -15,7 +15,7 @@
#include "base/strings/string_util.h"
#include "base/strings/stringprintf.h"
#include "base/time/time.h"
-#include "chrome/common/chrome_version_info.h"
+#include "components/version_info/version_info.h"
#include "content/public/browser/browser_thread.h"
#include "content/public/common/content_switches.h"
#include "net/base/mime_util.h"
@@ -147,11 +147,10 @@ void TraceCrashServiceUploader::DoUploadOnFileThread(
#error Platform not supported.
#endif
// VersionInfo::ProductNameAndVersionForUserAgent() returns a string like
// "Chrome/aa.bb.cc.dd", split out the part before the "/".
- chrome::VersionInfo version_info;
std::vector<std::string> product_components = base::SplitString(
- version_info.ProductNameAndVersionForUserAgent(), "/",
+ version_info::GetProductNameAndVersionForUserAgent(), "/",
base::TRIM_WHITESPACE, base::SPLIT_WANT_ALL);
DCHECK_EQ(2U, product_components.size());
std::string version;
@@ -147,11 +147,10 @@ void TraceCrashServiceUploader::DoUploadOnFileThread(
#error Platform not supported.
#endif
- // VersionInfo::ProductNameAndVersionForUserAgent() returns a string like
+ // version_info::GetProductNameAndVersionForUserAgent() returns a string like
// "Chrome/aa.bb.cc.dd", split out the part before the "/".
« no previous file with comments | « chrome/browser/sync/sync_stopped_reporter_unittest.cc ('k') | chrome/browser/ui/app_list/app_list_service_mac.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698